<template>
  <NavBar v-bind="props" class="large-title-navigation-bar">
    <div :class="['large-title-navigation-bar-wrapper']" :style="barStyle">
      <slot name="title">
        <span class="large-title-navigation-bar-title">{{ title }}</span>
      </slot>
    </div>
  </NavBar>
</template>

<script setup lang="ts">
import NavBar from './NavBar.vue';
import { commonNavigationBarProps } from './commonNavigationBar';
import { useSystemStore } from '@/stores/modules/system';
import { CSSProperties } from 'vue';
// import Taro from '@tarojs/taro';

defineOptions({
  name: 'LargeTitleNavigationBar',
});

const systemStore = useSystemStore();

const props = defineProps(commonNavigationBarProps);

const barStyle = computed(() => {
  const distance = systemStore.menuButtonWidth + systemStore.menuButtonRightDistance + 4;
  return {
    // paddingLeft: `${distance}px`,
    paddingRight: `${distance}px`,
    height: systemStore.navigationBarHeight + 'px',
  } as CSSProperties;
});
</script>

<style lang="scss">
@import '@/styles/common.scss';

.large-title-navigation-bar {
  background-color: transparent;
  position: relative;
  z-index: 1;
}

.large-title-navigation-bar-wrapper {
  width: 100%;
  line-height: 1;
  font-size: 40px;
  color: #fff;
  min-width: 0;
  position: relative;
  align-items: center;
  display: flex;
  font-weight: bold;
  padding-left: 30px;

  .large-title-navigation-bar-title {
    @include ellipsis;
  }
}
</style>
